library(httptest2)

options(osmapir.osmapir_version = "")
options(osmapir.user_agent = "osmapiR (https://github.com/ropensci/osmapiR)")
options(osmapir.R_CMD_check = TRUE)

set_osmapi_connection("testing")
